@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckCommit;
 # ABSTRACT: Git::Hooks plugin to enforce commit policies
-$Git::Hooks::CheckCommit::VERSION = '2.3.0';
+$Git::Hooks::CheckCommit::VERSION = '2.4.0';
 use 5.010;
 use utf8;
 use strict;
@@ -304,11 +304,19 @@ sub check_pre_commit {
 
     _setup_config($git);
 
+    # Grok author and committer information from git's envorinent variables, if
+    # they're defined. Sometimes they aren't...
+
+    my $author_name     = $ENV{GIT_AUTHOR_NAME}     || 'nobody';
+    my $author_email    = $ENV{GIT_AUTHOR_EMAIL}    || 'nobody@example.net';
+    my $committer_name  = $ENV{GIT_COMMITTER_NAME}  || $author_name;
+    my $committer_email = $ENV{GIT_COMMITTER_EMAIL} || $author_email;
+
     # Construct a fake commit object to pass to the error checking routines.
     my $commit = Git::Repository::Log->new(
         commit    => '<new>',
-        author    => "$ENV{GIT_AUTHOR_NAME} <$ENV{GIT_AUTHOR_EMAIL}> 1234567890 -0300",
-        committer => "$ENV{GIT_COMMITTER_NAME} <$ENV{GIT_COMMITTER_EMAIL}> 1234567890 -0300",
+        author    => "$author_name <$author_email> 1234567890 -0300",
+        committer => "$committer_name <$committer_email> 1234567890 -0300",
         message   => "Fake\n",
     );
 
@@ -393,7 +401,7 @@ Git::Hooks::CheckCommit - Git::Hooks plugin to enforce commit policies
 
 =head1 VERSION
 
-version 2.3.0
+version 2.4.0
 
 =head1 DESCRIPTION
 
@@ -641,7 +649,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2018 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
