@@ -2,7 +2,7 @@
 
 package Git::Hooks::Notify;
 # ABSTRACT: Git::Hooks plugin to notify users via email
-$Git::Hooks::Notify::VERSION = '2.3.0';
+$Git::Hooks::Notify::VERSION = '2.4.0';
 use 5.010;
 use utf8;
 use strict;
@@ -158,7 +158,7 @@ EOF
         # Force indentation of commit message lines
         $html =~ s:^( +):'&nbsp;' x length($1):egm;
         # Force indentation of commit numstat lines
-        $html =~ s[^(\d+)\t(\d+)\t]
+        $html =~ s[^(\d+|-)\t(\d+|-)\t]
             [$1 .
             '&nbsp;' x (8 - length($1)) .
             $2 .
@@ -267,7 +267,7 @@ Git::Hooks::Notify - Git::Hooks plugin to notify users via email
 
 =head1 VERSION
 
-version 2.3.0
+version 2.4.0
 
 =head1 DESCRIPTION
 
@@ -522,7 +522,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2018 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
